@@ -28,7 +28,7 @@ from datetime import datetime
 from pprint import pformat
 from threading import local
 
-version = '0.1.9'
+version = '0.2'
 
 def itemize_length(items):
     length = len(items)
@@ -43,6 +43,14 @@ def that_with_context(setup=None, teardown=None):
                 setup(context)
             try:
                 func(context, *args, **kw)
+            except TypeError, e:
+                fmt = '%s() takes no arguments'
+                err = unicode(e)
+                if (fmt % func.__name__) in err or (fmt % func.__name__.replace('test_', '', 1)) in err:
+                    func(*args, **kw)
+                else:
+                    raise e
+
             finally:
                 if callable(teardown):
                     teardown(context)
@@ -371,14 +379,22 @@ def within(**units):
     exc = []
     def dec(func):
         def wrap(*args, **kw):
-            start = datetime.now()
+            start = datetime.utcnow()
 
             try:
-                func(*args, **kw)
+                func(start, *args, **kw)
+            except TypeError, e:
+                fmt = '%s() takes no arguments'
+                err = unicode(e)
+                if (fmt % func.__name__) in err:
+                    func(*args, **kw)
+                else:
+                    exc.append(e)
+
             except Exception, e:
                 exc.append(e)
 
-            end = datetime.now()
+            end = datetime.utcnow()
             delta = (end - start)
             took = convert_to(delta.microseconds)
             print took, timeout
